@@ -50,7 +50,7 @@ GtkWidget *splash_label;
  *
  * Returns: Pointer to the window created
  */
- 
+
 GtkWidget*
 create_main_window (void)
 {
@@ -89,10 +89,10 @@ create_main_window (void)
   GError *error = NULL;
 
   /* Get Info */
-  
+
   cflist = get_options();
   pkgs_infos = pkg_info(cflist);
-  pkgsec_list = pkgs_infos[0]; 
+  pkgsec_list = pkgs_infos[0];
   pkgdesc_list = pkgs_infos[1];
   sec_list = sections(pkgsec_list);
 
@@ -101,8 +101,8 @@ create_main_window (void)
   gtk_window_set_position (GTK_WINDOW(win), GTK_WIN_POS_CENTER);
   gtk_window_set_default_size(GTK_WINDOW(win), 550, 480);
   gtk_signal_connect_object (GTK_OBJECT(win), "delete_event",
-			     GTK_SIGNAL_FUNC(gtk_main_quit),
-			     NULL);
+                             GTK_SIGNAL_FUNC(gtk_main_quit),
+                             NULL);
 
   vbox = gtk_vbox_new (0, 2);
   gtk_widget_show (vbox);
@@ -110,15 +110,15 @@ create_main_window (void)
   gtk_container_add (GTK_CONTAINER(win), vbox);
 
   menubar = create_menubar (win);
-  
+
   icon_pixbuf =  gdk_pixbuf_new_from_file ("/usr/share/pixmaps/gkdebconf-icon.xpm",&error);
-    if (!icon_pixbuf)
+  if (!icon_pixbuf)
     {
       fprintf (stderr, "Failed to load pixbuf file: %s.\n%s\n",
                "gkdebconf-icon.xpm", error->message);
       g_error_free (error);
     }
-    if (icon_pixbuf)
+  if (icon_pixbuf)
     {
       gtk_window_set_icon (GTK_WINDOW (win), icon_pixbuf);
       gdk_pixbuf_unref (icon_pixbuf);
@@ -136,7 +136,7 @@ create_main_window (void)
 
   scrolled_window = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
   gtk_widget_set_usize(scrolled_window, 120, 150);
   gtk_widget_show(scrolled_window);
@@ -156,7 +156,7 @@ create_main_window (void)
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(gtklist_sec), FALSE);
   cell = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes ("Sections ", cell,
-                                                      "text", 0, NULL);
+           "text", 0, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (gtklist_sec),
                                GTK_TREE_VIEW_COLUMN (column));
 
@@ -167,13 +167,13 @@ create_main_window (void)
 
   g_signal_connect (G_OBJECT (select_sec), "changed",
                     G_CALLBACK (list_item_selected), cflist);
-  
+
   /* fill with section names */
   gtk_list_store_set_strings (GTK_LIST_STORE(store_sec), sec_list);
- 
+
   gtk_widget_show (gtklist_sec);
 
-  gtk_container_add (GTK_CONTAINER (frame_list), scrolled_window); 
+  gtk_container_add (GTK_CONTAINER (frame_list), scrolled_window);
   gtk_box_pack_start (GTK_BOX(hbox), frame_list, TRUE, TRUE, 2);
 
   /* Description */
@@ -195,14 +195,14 @@ create_main_window (void)
 
   scrolled_window_desc = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window_desc),
-                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
+                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
   gtk_container_add (GTK_CONTAINER(scrolled_window_desc), text);
   gtk_widget_show(scrolled_window_desc);
 
-  gtk_container_add (GTK_CONTAINER (frame_desc), scrolled_window_desc); 
+  gtk_container_add (GTK_CONTAINER (frame_desc), scrolled_window_desc);
 
   gtk_box_pack_start (GTK_BOX(vbox), frame_desc, TRUE, TRUE, 0);
- 
+
   /* useful stuff */
   frame = gtk_frame_new (NULL);
   gtk_container_set_border_width (GTK_CONTAINER(frame), 0);
@@ -223,40 +223,40 @@ create_main_window (void)
 
   scrolled_window_cf = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window_cf),
-                                   GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  
+                                  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+
   /* Package list */
   store_cf = gtk_list_store_new (1, G_TYPE_STRING);
   gtklist_cf = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store_cf));
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(gtklist_cf), FALSE);
-    
+
   cell = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes ("Packages", cell,
-                                                      "text", 0, NULL);
+           "text", 0, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (gtklist_cf),
                                GTK_TREE_VIEW_COLUMN (column));
 
   gtk_container_add (GTK_CONTAINER(scrolled_window_cf), gtklist_cf);
-  
+
   select_cf = gtk_tree_view_get_selection (GTK_TREE_VIEW(gtklist_cf));
   gtk_tree_selection_set_mode (select_cf, GTK_SELECTION_SINGLE);
-  g_signal_connect(G_OBJECT (select_cf), "changed", 
-		   G_CALLBACK (cf_select), cflist);
+  g_signal_connect(G_OBJECT (select_cf), "changed",
+                   G_CALLBACK (cf_select), cflist);
 
-// Don't know how to make configure_cb function called when doubleclick on package in list
-//  g_signal_connect(G_OBJECT (select_cf), "double_click_event", 
-//		   GTK_SIGNAL_FUNC(configure_cb), GTK_TREE_SELECTION(select_cf));
+  // Don't know how to make configure_cb function called when doubleclick on package in list
+  //  g_signal_connect(G_OBJECT (select_cf), "double_click_event",
+  //		   GTK_SIGNAL_FUNC(configure_cb), GTK_TREE_SELECTION(select_cf));
 
   gtk_widget_show (gtklist_cf);
   gtk_widget_show(scrolled_window_cf);
-  
+
   /* fill with package names */
 
   gtk_list_store_set_strings (GTK_LIST_STORE(store_cf), cflist);
 
   gtk_box_pack_start(GTK_BOX(vbox_choose), toplabel, FALSE, FALSE, 2);
 
-//  gtk_box_pack_start(GTK_BOX(vbox_choose), gtklist_cf, TRUE, TRUE, 2);
+  //  gtk_box_pack_start(GTK_BOX(vbox_choose), gtklist_cf, TRUE, TRUE, 2);
   gtk_box_pack_start(GTK_BOX(vbox_choose), scrolled_window_cf, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX(hbox), frame, TRUE, TRUE, 2);
 
@@ -265,7 +265,7 @@ create_main_window (void)
 
   ok_btn = gtk_button_new ();
   gtk_signal_connect(GTK_OBJECT(ok_btn), "clicked",
-		     GTK_SIGNAL_FUNC(configure_cb),GTK_TREE_SELECTION(select_cf));
+                     GTK_SIGNAL_FUNC(configure_cb),GTK_TREE_SELECTION(select_cf));
   gtk_widget_show (ok_btn);
   ok_btn_alignment = gtk_alignment_new (0.5, 0.5, 0, 0);
   gtk_widget_show (ok_btn_alignment);
@@ -283,7 +283,7 @@ create_main_window (void)
 
   cancel_btn = gtk_button_new_from_stock ("gtk-quit");
   gtk_signal_connect_object (GTK_OBJECT(cancel_btn), "clicked",
-			     GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
+                             GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
   gtk_widget_show (cancel_btn);
 
   gtk_box_pack_start(GTK_BOX(hbox_buttons), cancel_btn, TRUE, TRUE, 2);
@@ -291,8 +291,8 @@ create_main_window (void)
 
   gtk_box_pack_start(GTK_BOX(vbox), hbox_buttons, FALSE, FALSE, 2);
 
-//  gtk_list_select_item(GTK_LIST(list), 0);
-  
+  //  gtk_list_select_item(GTK_LIST(list), 0);
+
   return win;
 }
 
@@ -312,54 +312,40 @@ create_menubar (GtkWidget *win)
 {
 
   GtkWidget *menubar;
-  GtkWidget *fe_toggle, *libgnome_toggle;
+  GtkWidget *fe_toggle;
   GtkAccelGroup *accel_group;
   GtkItemFactory *item_factory;
   GtkItemFactoryEntry menu_items[] = \
-    {
-      { _("/_File"), NULL, NULL, 0, "<Branch>" },
-      { _("/File/_Quit"), NULL, gtk_main_quit, 0, "<StockItem>","gtk-quit" },
-      { _("/_Options"), NULL, NULL, 0, "<Branch>" },
-      { _("/Options/_Remember last Frontend"), NULL, remember_fe_cb, 
-	0, "<ToggleItem>"},
-      { _("/Options/_Show an alert if libgnome is missing"), NULL, show_libgnome_missing_alert, 
-	0, "<ToggleItem>"},
-      { _("/Options/Frontends"), NULL, NULL, 0, "<Separator>" },
-      { _("/_Help"), NULL, NULL, 0, "<LastBranch>" },
-      { _("/Help/_About"), NULL, about_cb, 0, "<Item>" }
-    };
+                                     {
+                                       { _("/_File"), NULL, NULL, 0, "<Branch>" },
+                                       { _("/File/_Quit"), NULL, gtk_main_quit, 0, "<StockItem>","gtk-quit" },
+                                       { _("/_Options"), NULL, NULL, 0, "<Branch>" },
+                                       { _("/Options/_Remember last Frontend"), NULL, remember_fe_cb,
+                                         0, "<ToggleItem>"},
+                                       { _("/Options/Frontends"), NULL, NULL, 0, "<Separator>" },
+                                       { _("/_Help"), NULL, NULL, 0, "<LastBranch>" },
+                                       { _("/Help/_About"), NULL, about_cb, 0, "<Item>" }
+                                     };
   gint num_items = sizeof (menu_items) / sizeof (menu_items[0]);
 
   accel_group = gtk_accel_group_new ();
   item_factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, "<main>",
-				       accel_group);
+                                       accel_group);
   gtk_item_factory_create_items (item_factory, num_items, menu_items, NULL);
   gtk_window_add_accel_group (GTK_WINDOW(win), accel_group);
   menubar = gtk_item_factory_get_widget (item_factory, "<main>");
 
   fe_toggle = gtk_item_factory_get_widget (GTK_ITEM_FACTORY(item_factory),
-					   _("<main>/Options/Remember last Frontend"));
- 
-  libgnome_toggle = gtk_item_factory_get_widget (GTK_ITEM_FACTORY(item_factory),
-					   _("<main>/Options/Show an alert if libgnome is missing"));
-  
-// check if the user request gkdebconf to remember frontend
-// only for check menu item.
+              _("<main>/Options/Remember last Frontend"));
+
+  // check if the user request gkdebconf to remember frontend
+  // only for check menu item.
   {
     gchar *remember_fe = NULL;
     remember_fe = read_config ("remember_frontend");
     if (!strcmp (remember_fe, "yes") && fe_toggle)
       GTK_CHECK_MENU_ITEM(fe_toggle)->active = TRUE;
     g_free (remember_fe);
-	  }
-// check if the user request gkdebconf to show alert when lignome is missing
-// only for check menu item.
-  {
-    gchar *libgnome_alert = NULL;
-    libgnome_alert = read_config ("libgnome_alert");
-    if (!strcmp (libgnome_alert, "yes") && libgnome_toggle)
-      GTK_CHECK_MENU_ITEM(libgnome_toggle)->active = TRUE;
-    g_free (libgnome_alert);
   }
   return menubar;
 }
@@ -407,17 +393,17 @@ show_about_window (GtkWidget *mainwin, gchar *msg, gchar *iname)
   GtkWidget *about_label;
 
   about_win = gtk_dialog_new_with_buttons ("GkDebconf", GTK_WINDOW(mainwin),
-					   GTK_DIALOG_MODAL,
-					   GTK_STOCK_CLOSE,
-					   GTK_RESPONSE_CLOSE,
-					   NULL);
-					   
+              GTK_DIALOG_MODAL,
+              GTK_STOCK_CLOSE,
+              GTK_RESPONSE_CLOSE,
+              NULL);
+
   gtk_window_set_position (GTK_WINDOW(about_win), GTK_WIN_POS_CENTER);
 
   /* box */
   hbox = gtk_hbox_new (FALSE, 2);
   gtk_container_add (GTK_CONTAINER(GTK_DIALOG(about_win)->vbox),
-		     hbox);
+                     hbox);
 
   /* image */
   image = create_gkdebconf_image(iname);
@@ -445,7 +431,7 @@ show_about_window (GtkWidget *mainwin, gchar *msg, gchar *iname)
  *
  */
 
-void 
+void
 gk_dialog (GtkMessageType type, gchar *format, ...)
 {
   GtkWidget *diag_win;
@@ -458,12 +444,12 @@ gk_dialog (GtkMessageType type, gchar *format, ...)
   va_end(ap);
 
   diag_win = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
-				     type, GTK_BUTTONS_CLOSE,
-				     msg);
-			     
+                                     type, GTK_BUTTONS_CLOSE,
+                                     msg);
+
   gtk_signal_connect_object (GTK_OBJECT(diag_win), "delete_event",
-			     GTK_SIGNAL_FUNC(gtk_main_quit), 
-			     NULL);
+                             GTK_SIGNAL_FUNC(gtk_main_quit),
+                             NULL);
   gtk_window_set_position (GTK_WINDOW(diag_win), GTK_WIN_POS_CENTER);
   gtk_window_set_resizable (GTK_WINDOW(diag_win), FALSE);
 
@@ -486,7 +472,7 @@ gk_dialog (GtkMessageType type, gchar *format, ...)
 void set_description(GtkWidget *text, gchar *pkg)
 {
   GtkTextBuffer *buffer;
- 
+
   buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
   gtk_text_buffer_set_text(buffer, pkg, -1);
   gtk_text_view_set_buffer(GTK_TEXT_VIEW(text), buffer);
@@ -505,11 +491,12 @@ void gtk_list_store_set_strings (GtkListStore *store, GList *list)
   GtkTreeIter iter;
   GList *node = g_list_copy(list);
   gtk_list_store_clear(store);
-  while (node != NULL) {
-     gtk_list_store_append(store, &iter);
-     gtk_list_store_set(store, &iter, 0, node->data, -1);
-     node = node->next;
-  }
+  while (node != NULL)
+    {
+      gtk_list_store_append(store, &iter);
+      gtk_list_store_set(store, &iter, 0, node->data, -1);
+      node = node->next;
+    }
 }
 
 /**
@@ -527,7 +514,7 @@ void list_item_selected(GtkTreeSelection *selection, gpointer data)
   GtkTreeView *tree_view;
   GtkTreeModel *model;
   GtkTreePath *path;
-  
+
   GList *cf_items = NULL;
   gchar *item_data_string;
   gchar *str, *p;
@@ -536,23 +523,27 @@ void list_item_selected(GtkTreeSelection *selection, gpointer data)
   GList *pkgsec_list_copy = g_list_copy(pkgsec_list);
 
   tree_view = gtk_tree_selection_get_tree_view (selection);
-	
-  if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+
+  if (gtk_tree_selection_get_selected (selection, &model, &iter))
+    {
       gtk_tree_model_get (model, &iter, 0, &item_data_string, -1);
- 
-    while (pkgsec_list_copy) {
-      str = pkgsec_list_copy->data;
-  
-      if (strcmp(str, item_data_string) == 0) {
-        p = g_list_nth_data(cflist, i);
-        cf_items = g_list_append(cf_items, p);
-      }
-    
-      pkgsec_list_copy = pkgsec_list_copy->next;
-      i++;
+
+      while (pkgsec_list_copy)
+        {
+          str = pkgsec_list_copy->data;
+
+          if (strcmp(str, item_data_string) == 0)
+            {
+              p = g_list_nth_data(cflist, i);
+              cf_items = g_list_append(cf_items, p);
+            }
+
+          pkgsec_list_copy = pkgsec_list_copy->next;
+          i++;
+        }
     }
-  }
-  if(g_list_length(cf_items) == 0) cf_items = g_list_copy(cflist);
+  if(g_list_length(cf_items) == 0)
+    cf_items = g_list_copy(cflist);
 
   gtk_list_store_set_strings (GTK_LIST_STORE(store_cf), cf_items);
 
@@ -580,14 +571,15 @@ void cf_select(GtkTreeSelection *selection, gpointer data)
   gint selected;
   GList *cflist = (GList *) data;
 
-  if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+  if (gtk_tree_selection_get_selected (selection, &model, &iter))
+    {
       gtk_tree_model_get (model, &iter, 0, &package, -1);
-  if (strlen(package) == 0)
-    return;
-  selected = g_list_position(cflist, g_list_find_custom(cflist,package,sort_configs));
-  set_description(text, g_list_nth_data (pkgdesc_list, selected));
-  g_free (package);
-  }
+      if (strlen(package) == 0)
+        return;
+      selected = g_list_position(cflist, g_list_find_custom(cflist,package,sort_configs));
+      set_description(text, g_list_nth_data (pkgdesc_list, selected));
+      g_free (package);
+    }
 
 }
 
@@ -638,25 +630,25 @@ gk_splash ()
  *
  */
 
-void 
+void
 about_cb (GtkWidget *w, gpointer data)
 {
   char msg[1024];
 
-  sprintf (msg, 
-	   _("GkDebconf %s\n\n"
-	     "This program is intended for those who are not\n"
-	     "used to the Debian packaging system and don't\n"
-	     "know how to find what packages can be reconfigured\n"
-	     "and how to reconfigure them.\n\n"
-	     "Authors:\n\n"
-	     "Agney Lopes Roth Ferraz <agney@users.sourceforge.net> \n"
-		 "Gustavo Noronha Silva <kov@debian.org>\n\n"
-		 "GUI improvements for version 1.2 by:\n\n"
-	     "Mantas Kriauciunas <mantas@akl.lt> \n"
-		 "Martynas Jocius <mjoc@delfi.lt> \n"
-	     ),
-	   VERSION);
+  sprintf (msg,
+           _("GkDebconf %s\n\n"
+             "This program is intended for those who are not\n"
+             "used to the Debian packaging system and don't\n"
+             "know how to find what packages can be reconfigured\n"
+             "and how to reconfigure them.\n\n"
+             "Authors:\n\n"
+             "Agney Lopes Roth Ferraz <agney@users.sourceforge.net> \n"
+             "Gustavo Noronha Silva <kov@debian.org>\n\n"
+             "GUI improvements for version 1.2 by:\n\n"
+             "Mantas Kriauciunas <mantas@akl.lt> \n"
+             "Martynas Jocius <mjoc@delfi.lt> \n"
+            ),
+           VERSION);
 
   show_about_window (main_window, msg, "gkdebconf-splash.xpm");
 }
@@ -678,9 +670,9 @@ gk_dialog_for_gconf (  gchar *key, gchar *format, ... )
   GtkWidget *show_message_again;
   GtkWidget *dialog_action_area_libgnome_alert;
   GtkWidget *closebutton_libgnome_alert;
-  GdkPixbuf *icon_pixbuf; 
+  GdkPixbuf *icon_pixbuf;
   GError *error = NULL;
-  
+
 
   va_list ap;
   gchar *msg;
@@ -702,7 +694,7 @@ gk_dialog_for_gconf (  gchar *key, gchar *format, ... )
                "/usr/share/pixmaps/gkdebconf-icon.xpm", error->message);
       g_error_free (error);
     }
-   else
+  else
     {
       gtk_window_set_icon (GTK_WINDOW (libgnome_alert_dialog), icon_pixbuf);
       gdk_pixbuf_unref (icon_pixbuf);
@@ -718,7 +710,7 @@ gk_dialog_for_gconf (  gchar *key, gchar *format, ... )
   gtk_container_set_border_width (GTK_CONTAINER (vbox_libgnome_alert), 4);
 
   message = gtk_label_new ( msg );
-  
+
   gtk_box_pack_start (GTK_BOX (vbox_libgnome_alert), message, TRUE, FALSE, 0);
   gtk_label_set_justify (GTK_LABEL (message), GTK_JUSTIFY_LEFT);
 
@@ -746,8 +738,8 @@ gk_dialog_for_gconf (  gchar *key, gchar *format, ... )
   gtk_dialog_run (GTK_DIALOG (libgnome_alert_dialog));
 
   g_free(msg);
-   if (GTK_TOGGLE_BUTTON(show_message_again)->active)
-	  write_config (key, "no");
+  if (GTK_TOGGLE_BUTTON(show_message_again)->active)
+    write_config (key, "no");
 
   gtk_widget_destroy (libgnome_alert_dialog);
 
